==> backend.ai-kernel-runner-1.0.3.tar.gz: backend.ai-kernel-runner-1.0.3/ai/backend/kernel/cpp/__init__.py <==
import logging
import os
from pathlib import Path
import shlex
import tempfile

from .. import BaseRunner

log = logging.getLogger()

DEFAULT_CFLAGS = '-Wall'
DEFAULT_LDFLAGS = '-lrt -lm -pthread'
CHILD_ENV = {
    'TERM': 'xterm',
    'LANG': 'C.UTF-8',
    'SHELL': '/bin/ash',
    'USER': 'work',
    'HOME': '/home/work',
    'PATH': '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
    'LD_PRELOAD': os.environ.get('LD_PRELOAD', '/home/sorna/patch-libs.so'),
}


class Runner(BaseRunner):

    log_prefix = 'cpp-kernel'

    def __init__(self):
        super().__init__()
        self.child_env.update(CHILD_ENV)

    async def init_with_loop(self):
        pass

    async def build_heuristic(self):
        if Path('main.cpp').is_file():
            cppfiles = Path('.').glob('**/*.cpp')
            cppfiles = ' '.join(map(lambda p: shlex.quote(str(p)), cppfiles))
            cmd = (
                f'g++ {cppfiles} {DEFAULT_CFLAGS} -o ./main {DEFAULT_LDFLAGS};'
                f'./main'
            )
            await self.run_subproc(cmd)
        else:
            log.error('cannot find build script ("Makefile") '
                      'or the main file ("main.cpp").')

    async def execute_heuristic(self):
        if Path('./main').is_file():
            await self.run_subproc('./main')
        elif Path('./a.out').is_file():
            await self.run_subproc('./a.out')
        else:
            log.error('cannot find executable ("a.out" or "main").')

    async def query(self, code_text):
        with tempfile.NamedTemporaryFile(suffix='.cpp', dir='.') as tmpf:
            tmpf.write(code_text.encode('utf8'))
            tmpf.flush()
            cmd = (
                f'g++ {tmpf.name} {DEFAULT_CFLAGS} -o ./main {DEFAULT_LDFLAGS}'
                f'&& ./main'
            )
            await self.run_subproc(cmd)

    async def complete(self, data):
        return []

    async def interrupt(self):
        # subproc interrupt is already handled by BaseRunner
        pass

==> backend.ai-kernel-runner-1.0.8.tar.gz: backend.ai-kernel-runner-1.0.8/ai/backend/kernel/cpp/__init__.py <==
import logging
import os
from pathlib import Path
import shlex
import tempfile

from .. import BaseRunner

log = logging.getLogger()

DEFAULT_CFLAGS = '-Wall'
DEFAULT_LDFLAGS = '-lrt -lm -pthread -ldl'
CHILD_ENV = {
    'TERM': 'xterm',
    'LANG': 'C.UTF-8',
    'SHELL': '/bin/ash',
    'USER': 'work',
    'HOME': '/home/work',
    'PATH': '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
    'LD_PRELOAD': os.environ.get('LD_PRELOAD', '/home/sorna/patch-libs.so'),
}


class Runner(BaseRunner):

    log_prefix = 'cpp-kernel'

    def __init__(self):
        super().__init__()
        self.child_env.update(CHILD_ENV)

    async def init_with_loop(self):
        pass

    async def build_heuristic(self):
        if Path('main.cpp').is_file():
            cppfiles = list(Path('.').glob('**/*.cpp'))
            ofiles = [Path(p.stem + '.o') for p in cppfiles]
            for cppf in cppfiles:
                cmd = f'g++ -c {cppf} {DEFAULT_CFLAGS}'
                await self.run_subproc(cmd)
            cppfiles = ' '.join(map(lambda p: shlex.quote(str(p)), cppfiles))
            ofiles = ' '.join(map(lambda p: shlex.quote(str(p)), ofiles))
            cmd = f'g++ {ofiles} {DEFAULT_LDFLAGS} -o ./main'
            await self.run_subproc(cmd)
        else:
            log.error('cannot find build script ("Makefile") '
                      'or the main file ("main.cpp").')

    async def execute_heuristic(self):
        if Path('./main').is_file():
            await self.run_subproc('./main')
        elif Path('./a.out').is_file():
            await self.run_subproc('./a.out')
        else:
            log.error('cannot find executable ("a.out" or "main").')

    async def query(self, code_text):
        with tempfile.NamedTemporaryFile(suffix='.cpp', dir='.') as tmpf:
            tmpf.write(code_text.encode('utf8'))
            tmpf.flush()
            cmd = (
                f'g++ {tmpf.name} {DEFAULT_CFLAGS} -o ./main {DEFAULT_LDFLAGS}'
                f'&& ./main'
            )
            await self.run_subproc(cmd)

    async def complete(self, data):
        return []

    async def interrupt(self):
        # subproc interrupt is already handled by BaseRunner
        pass
